Method: RTKIT::ImageSeries#set_resolution
- Defined in:
- lib/rtkit/image_series.rb
#set_resolution(columns, rows, options = {}) ⇒ Object
Sets the resolution of all images in this image series. The images will either be expanded or cropped depending on whether the specified resolution is bigger or smaller than the existing one.
Parameters
-
columns– Integer. The number of columns applied to the cropped/expanded image series. -
rows– Integer. The number of rows applied to the cropped/expanded image series.
Options
-
:hor– Symbol. The side (in the horisontal image direction) to apply the crop/border (:left, :right or :even (default)). -
:ver– Symbol. The side (in the vertical image direction) to apply the crop/border (:bottom, :top or :even (default)).
239 240 241 242 243 |
# File 'lib/rtkit/image_series.rb', line 239 def set_resolution(columns, rows, ={}) @images.each do |img| img.set_resolution(columns, rows, ) end end |